<?php

namespace Drupal\scss\Services;

// This is the interface we are going to implement.
use Drupal;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

// This class contains the event we want to subscribe to.
use Symfony\Component\HttpKernel\KernelEvents;

// Our event listener method will receive one of these.
use Symfony\Component\HttpKernel\Event\GetResponseEvent;

/**
 * Listens to page loads and compiles if needed.
 *
 * @category Developer_Tools
 * @package Drupal\scss
 * @author Jason Salter <jason@fivepaths.com>
 * @author Tyler Brown Cifu Shuster <tyler@fivepaths.com>
 * @license GPLv3 https://www.gnu.org/licenses/gpl-3.0.html
 * @link https://www.drupal.org/project/scss
 */
class ScssMonitor implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::REQUEST][] = ['compileIfNeeded'];
    return $events;
  }

  /**
   * The function which runs on each page load to check if SCSS is active.
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
   *   The event to which to respond. Not used.
   */
  public function compileIfNeeded(GetResponseEvent $event) {

    // Check to see if we're monitoring for SASS changes.
    if (!Drupal::config('scss.settings')->get('active')) {
      return;
    }

    // We're monitoring - create a compiler.
    $scssCompiler = new ScssCompiler();
    $scssCompiler->compileScss();

  }

}
